@@ -6,15 +6,6 @@
 #include "VecGeom/volumes/Hype.h"
 #include "VecGeom/base/Global.h"
 
-//#if defined(VECGEOM_TEST_BENCHMARK) && defined(VECGEOM_ROOT)
-#ifdef VECGEOM_ROOT
-#include "TGeoHype.h"
-#endif
-
-#ifdef VECGEOM_GEANT4
-#include "G4Hype.hh"
-#endif
-
 namespace vecgeom {
 inline namespace VECGEOM_IMPL_NAMESPACE {
 
@@ -36,21 +27,7 @@ VPlacedVolume const *PlacedHype::ConvertToUnspecialized() const
   return new SimpleHype(GetLabel().c_str(), GetLogicalVolume(), GetTransformation());
 }
 
-#ifdef VECGEOM_ROOT
-TGeoShape const *PlacedHype::ConvertToRoot() const
-{
-  return GetUnplacedVolume()->ConvertToRoot(GetName());
-}
-#endif
-
-#ifdef VECGEOM_GEANT4
-G4VSolid const *PlacedHype::ConvertToGeant4() const
-{
-  return GetUnplacedVolume()->ConvertToGeant4(GetName());
-}
-#endif
-
-#endif // VECGEOM_TEST_BENCHMARK
+#endif // VECGEOM_CUDA
 
 } // namespace VECGEOM_IMPL_NAMESPACE
 
